@@ -130,7 +130,7 @@ pub trait CSharpWriter {
 
     fn write_documentation(&self, w: &mut IndentWriter, documentation: &Documentation) -> Result<(), Error> {
         for line in documentation.lines() {
-            indented!(w, r#"/// {}"#, line)?;
+            indented!(w, r#"///{}"#, line)?;
         }
 
         Ok(())
@@ -305,6 +305,10 @@ pub trait CSharpWriter {
         indented!(w, r#"{{"#)?;
         indented!(w, [_], r#"public static readonly {} True = new Bool {{ value =  1 }};"#, type_name)?;
         indented!(w, [_], r#"public static readonly {} False = new Bool {{ value =  0 }};"#, type_name)?;
+        indented!(w, [_], r#"public Bool(bool b)"#)?;
+        indented!(w, [_], r#"{{"#)?;
+        indented!(w, [_ _ ], r#"value = (byte) (b ? 1 : 0);"#)?;
+        indented!(w, [_], r#"}}"#)?;
         indented!(w, [_], r#"byte value;"#)?;
         indented!(w, [_], r#"public bool Is => value == 1;"#)?;
         indented!(w, r#"}}"#)?;
